@@ -22,7 +22,7 @@
 report_overview <- function(formatted.ACB, today.data = TRUE, tax.year = "all",
                             local.timezone = Sys.timezone(), list.prices = NULL, force = FALSE) {
   if (isTRUE(today.data) && isFALSE(curl::has_internet())) {
-    message("Attention: You need Internet access to use the `today.data == TRUE` argument. The today.data argument has been set to `FALSE` automatically.")
+    message("You need Internet access to use the `today.data == TRUE` argument. The today.data argument has been set to `FALSE` automatically.")
     today.data <- FALSE
   }
 
